Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 50499db3edb064e34c9499ea6d45944becd8d2fb..20afe472854e73c45e41fddfa38b091cbf24a53f 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -7600,6 +7600,7 @@ class JSFunction: public JSObject { |
// [context]: The context for this function. |
inline Context* context(); |
inline void set_context(Object* context); |
+ inline JSObject* global_proxy(); |
// [code]: The generated code object for this function. Executed |
// when the function is invoked, e.g. foo() or new foo(). See |
@@ -7853,8 +7854,8 @@ class GlobalObject: public JSObject { |
// [global context]: the most recent (i.e. innermost) global context. |
DECL_ACCESSORS(global_context, Context) |
- // [global receiver]: the global receiver object of the context |
- DECL_ACCESSORS(global_receiver, JSObject) |
+ // [global proxy]: the global proxy object of the context |
+ DECL_ACCESSORS(global_proxy, JSObject) |
// Retrieve the property cell used to store a property. |
PropertyCell* GetPropertyCell(LookupResult* result); |
@@ -7865,8 +7866,8 @@ class GlobalObject: public JSObject { |
static const int kBuiltinsOffset = JSObject::kHeaderSize; |
static const int kNativeContextOffset = kBuiltinsOffset + kPointerSize; |
static const int kGlobalContextOffset = kNativeContextOffset + kPointerSize; |
- static const int kGlobalReceiverOffset = kGlobalContextOffset + kPointerSize; |
- static const int kHeaderSize = kGlobalReceiverOffset + kPointerSize; |
+ static const int kGlobalProxyOffset = kGlobalContextOffset + kPointerSize; |
+ static const int kHeaderSize = kGlobalProxyOffset + kPointerSize; |
private: |
DISALLOW_IMPLICIT_CONSTRUCTORS(GlobalObject); |